@@ -1,8 +1,9 @@
-# $Id: ObjectDriver.pm 560 2009-01-28 18:37:28Z btrott $
+# $Id$
 
 package Data::ObjectDriver;
 use strict;
 use warnings;
+use 5.006_001;
 use Class::Accessor::Fast;
 
 use base qw( Class::Accessor::Fast );
@@ -10,7 +11,7 @@ use Data::ObjectDriver::Iterator;
 
 __PACKAGE__->mk_accessors(qw( pk_generator txn_active ));
 
-our $VERSION = '0.06';
+our $VERSION = '0.09';
 our $DEBUG = $ENV{DOD_DEBUG} || 0;
 our $PROFILE = $ENV{DOD_PROFILE} || 0;
 our $PROFILER;
@@ -106,6 +107,7 @@ sub debug {
 sub profiler {
     my $driver = shift;
     my ($sql) = @_;
+    local $@;
     $PROFILER ||= eval {
         require Data::ObjectDriver::Profiler;
         Data::ObjectDriver::Profiler->new;
@@ -201,11 +203,6 @@ caching and partitioning layers, allowing you to spread data across multiple
 physical databases, without your application code needing to know where the
 data is stored.
 
-It's currently considered ALPHA code. The API is largely fixed, but may seen
-some small changes in the future. For what it's worth, the likeliest area
-for changes are in the syntax for the I<search> method, and would most
-likely not break much in the way of backwards compatibility.
-
 =head1 METHODOLOGY
 
 I<Data::ObjectDriver> provides you with a framework for building
@@ -613,6 +610,14 @@ I<Data::ObjectDriver::Profiler> instance:
 Then see the documentation for I<Data::ObjectDriver::Profiler> to see the
 methods on that class.
 
+In some applications there are phases of execution in which no I/O
+operations should occur, but sometimes it's difficult to tell when,
+where, or if those I/O operations are happening.  One approach to
+surfacing these situations is to set, either globally or locally,
+the $Data::ObjectDriver::RESTRICT_IO flag.  If set, this will tell
+Data::ObjectDriver to die with some context rather than executing
+network calls for data.
+
 
 =head1 TRANSACTIONS
 
